﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using Microdesk.SkillPortal.DomainPersistence;
using Microdesk.SkillPortal.DomainModel;
using Rhino.Commons;
using Microdesk.SkillPortal.DomainServices;
using SkillPortalSite.ViewModels;

namespace SkillPortalSite.Controllers
{
    public class EmployeeController : Controller
    {

        private IUserService _userService;
        private IEmployeeRepository _employeeRepository;
        private ISkillTypeRepository _skillTypeRepository;

        /// <summary>
        /// Initializes a new instance of the EmployeeController class.
        /// </summary>
        public EmployeeController(ISkillTypeRepository skillTypeRepository, IUserService userService, IEmployeeRepository employeeRepository)
        {
            _employeeRepository = employeeRepository;
            _userService = userService;
            _skillTypeRepository = skillTypeRepository;
        }

        public ActionResult Index()
        {
            // Add action logic here
            throw new NotImplementedException();
        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ViewResult SelectSkills()
        {
            IList<SkillType> skills;
            Employee currentEmployee;
            using (UnitOfWork.Start())
            {
                skills = _skillTypeRepository.GetAllSkills();
                currentEmployee = _userService.GetEmployeeForCurrentUser();
            }

            SelectSkillsViewModel selectSkillsViewModel = new SelectSkillsViewModel();

            selectSkillsViewModel.SkillTypes = skills;


            selectSkillsViewModel.Employee = currentEmployee;

            return View("SelectSkills", selectSkillsViewModel);

        }


        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult SelectSkills(Guid[] selectedSkills)
        {
            Employee employee;

            using (UnitOfWork.Start())
            {
                employee = _userService.GetEmployeeForCurrentUser();

                foreach (Guid g in selectedSkills)
                {
                    SkillType skillType = _skillTypeRepository.GetSkillType(g);

                    employee.AddSkill(new Skill(skillType));
                }

                employee = _employeeRepository.SaveOrUpdateEmployee(employee);

                UnitOfWork.Current.Flush();
            }

            return RedirectToAction("SelectSkills");
        }
    }
}
