﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using Rhino.Commons.HttpModules;
using Castle.Windsor;
using Rhino.Commons;
using Microdesk.SkillPortal.DomainPersistence;
using Microdesk.SkillPortal.DomainServices;
using Castle.MicroKernel.Registration;
using SkillPortalSite.Controllers;



namespace SkillPortalSite
{
    // Note: For instructions on enabling IIS6 or IIS7 classic mode, 
    // visit http://go.microsoft.com/?LinkId=9394801

    public class MvcApplication : UnitOfWorkApplication   //System.Web.HttpApplication
    {
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            routes.MapRoute(
                "Default",                                              // Route name
                "{controller}/{action}/{id}",                           // URL with parameters
                new { controller = "Home", action = "Index", id = "" }  // Parameter defaults
            );

        }



        public override void Application_Start(object sender, EventArgs e)
        {
            base.Application_Start(sender, e);
            RegisterRoutes(RouteTable.Routes);

            ControllerBuilder.Current.SetControllerFactory(typeof(RhinoIoCControllerFactory));


        }



        protected override IWindsorContainer CreateContainer(string windsorConfig)
        {
            IWindsorContainer container = new WindsorContainer();

            container.Register(Component.For<IUnitOfWorkFactory>().ImplementedBy<NHibernateUnitOfWorkFactory>());

            container.Register(Component.For<ISkillTypeRepository>().ImplementedBy<SkillTypeRepository>().LifeStyle.Is(Castle.Core.LifestyleType.Transient));
            container.Register(Component.For<IUserService>().ImplementedBy<UserService>().LifeStyle.Is(Castle.Core.LifestyleType.Transient));
            container.Register(Component.For<IEmployeeRepository>().ImplementedBy<EmployeeRepository>().LifeStyle.Is(Castle.Core.LifestyleType.Transient));

            container.Register(AllTypes.Of<IController>()
                .FromAssembly(typeof(HomeController).Assembly)
                .Configure(t => t.Named(t.Implementation.Name.ToUpper())
                .LifeStyle.Is(Castle.Core.LifestyleType.Transient)));

            return container;
        }


        public class RhinoIoCControllerFactory : IControllerFactory
        {

            public IController CreateController(RequestContext requestContext, string controllerName)
            {
                return IoC.Resolve<IController>((controllerName + "Controller").ToUpper());
            }

            public void ReleaseController(IController controller)
            {
                IoC.Container.Release(controller);
            }

        }

    }



}