﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;


namespace Microdesk.SkillPortal.DomainModel.Tests
{
    [TestFixture]
    public class EmployeeTests : Microdesk.Utility.UnitTest.UnitTestBase
    {

        [Test]
        public void CanAddSkillToEmployee()
        {
            Employee emp = new Employee();

            emp.AddSkill(new Skill(new SkillType()));

            Assert.IsNotNull(emp.Skills);
        }

        [Test]
        public void CanAddMoreThanOneDifferentSkillToEmployee()
        {
            Employee employee = new Employee();

            SkillType skillType1 = new SkillType();
            base.SetInstanceFieldValue(skillType1, "_persistenceId", new Guid("11111111-1111-1111-1111-111111111111"));

            SkillType skillType2 = new SkillType();
            base.SetInstanceFieldValue(skillType2, "_persistenceId", new Guid("22222222-2222-2222-2222-222222222222"));

            Skill skill1 = new Skill(skillType1);
            base.SetInstanceFieldValue(skill1, "_persistenceId", new Guid("11111111-1111-1111-1111-111111111111"));

            Skill skill2 = new Skill(skillType2);
            base.SetInstanceFieldValue(skill2, "_persistenceId", new Guid("22222222-2222-2222-2222-222222222222"));

            employee.AddSkill(skill1);
            employee.AddSkill(skill2);

            Assert.IsTrue(employee.Skills.Contains(skill1), "skill1 wasn't in the collection");
            Assert.IsTrue(employee.Skills.Contains(skill2), "skill2 wasn't in the collection");
        }


        [Test]
        public void CannotAddSameSkillToEmployeeMoreThanOnce()
        {
            Employee employee = new Employee();

            SkillType skillType1 = new SkillType();
            base.SetInstanceFieldValue(skillType1, "_persistenceId", new Guid("11111111-1111-1111-1111-111111111111"));

            Skill skill1 = new Skill(skillType1);
            base.SetInstanceFieldValue(skill1, "_persistenceId", new Guid("11111111-1111-1111-1111-111111111111"));

            Skill skill2 = new Skill(skillType1);
            base.SetInstanceFieldValue(skill2, "_persistenceId", new Guid("22222222-2222-2222-2222-222222222222"));

            employee.AddSkill(skill1);
            employee.AddSkill(skill2);

            Assert.IsTrue(employee.Skills.Contains(skill1), "skill1 wasn't in the collection");
            Assert.IsFalse(employee.Skills.Contains(skill2), "skill2 was in the collection");
        }


        [Test]
        public void CanCreateEmployeeWithDefaultConstructor()
        {
            Employee emp = new Employee();

            Assert.IsNotNull(emp);
        }

        [Test]
        public void CannotAddToSkillsCollectionDirectly()
        {
            Employee emp = new Employee();

            try
            {
                emp.Skills.Add(new Skill( new SkillType()));
                Assert.Fail("Expected NotSupportedException not thrown!");
            }
            catch (NotSupportedException)
            {
                
            }
        }

    }
}
