﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using Microdesk.SkillPortal.DomainModel;
using Microdesk.SkillPortal.DomainPersistence;
using Castle.Windsor;
using Rhino.Commons;

namespace PersitenceTests
{
    [TestFixture]
    public class EmployeePersistenceTests : RepositoryPersistenceTestBase
    {


        [Test]
        public void CanGetEmployeeById()
        {

            EmployeeRepository empRepos = new EmployeeRepository();

            using (UnitOfWork.Start())
            {
                Guid theGuid = new Guid("11111111-1111-1111-1111-111111111111");
                Employee emp = empRepos.GetEmployee(theGuid);

                Assert.IsNotNull(emp);

                Assert.AreEqual(theGuid, emp.Id);
            }

        }

        [Test]
        public void CanSaveEmployeeWithAddedSkill()
        {
            EmployeeRepository empRepos = new EmployeeRepository();

            int initialSkillsCount;

            Guid theGuid = new Guid("11111111-1111-1111-1111-111111111111");
            using (UnitOfWork.Start())
            {
                Employee emp = empRepos.GetEmployee(theGuid);

                initialSkillsCount = emp.Skills.Count;

                SkillType newSkillType = new SkillType() { Description = "SomeNewSkillType" };
                Skill newSkill = new Skill(newSkillType);
                emp.AddSkill(newSkill);

                SkillTypeRepository skillTypeRepository = new SkillTypeRepository();

                skillTypeRepository.SaveOrUpdateSkill(newSkillType);

                empRepos.Save(emp);

                UnitOfWork.Current.Flush();
            }

            using (UnitOfWork.Start())
            {
                Employee emp = empRepos.GetEmployee(theGuid);

                Assert.AreEqual(emp.Skills.Count, initialSkillsCount + 1);

            }




        }

    }
}
